@@ -1,7 +1,8 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2018-2022, by Samuel Williams.
+# Copyright, 2018-2023, by Samuel Williams.
+# Copyright, 2019, by Janko Marohnić.
 
 require 'protocol/websocket/connection'
 require 'protocol/websocket/headers'
@@ -30,31 +31,17 @@ module Async
 				end
 			end
 			
-			def initialize(framer, protocol = nil, response: nil, **options)
+			def initialize(framer, protocol = nil, **options)
 				super(framer, **options)
 				
 				@protocol = protocol
-				@response = response
 			end
 			
 			def reusable?
 				false
 			end
 			
-			def close
-				super
-				
-				if @response
-					@response.finish
-					@response = nil
-				end
-			end
-			
 			attr :protocol
-			
-			def call
-				self.close
-			end
 		end
 	end
 end
